.. _head_pose.neck_angle:

Neck Flexion Angle
==================

.. automodule:: eyetrace.head_pose.neck_angle
   :members:
   :undoc-members:
   :show-inheritance:

Estimates neck flexion angle from head orientation. Currently returns the head
pitch as a proxy; a future version may incorporate shoulder landmarks for more
accurate measurement.